# rmtoo-art-req-dep-graph2

NAME
DESCRIPTION
CONFIGURATION and SETUP
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-art-req-dep-graph2 - requirements management tool: requirements dependency graph shaping 2

## DESCRIPTION

The rmtoo requirement management tool is able to output one topic and all possible subtopics including the containing requirements in a requirement dependency graph.

The rmtoo-art-req-dep-graph2 module mostly generates the same output as described in rmtoo-art-req-dep-graph(1) except one difference: requirements related to one topic are grouped together as a cluster, i. e. are drawn near to each other with a box around them.

This graph gives a good impression about the quality of the topic grouping: if there are mostly all links inside the box with only a few to the outside, the topic grouping is done well. If there are mostly no connections inside the box and a lot of to the outside, you should think about rearranging the topic grouping.

## CONFIGURATION and SETUP

The key for the configuration must be graph2.

All other information about configuration and calling dot can be found in rmtoo-art-req-dep-graph(1).

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later